package net.pingex.dcf.core;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import sx.blah.discord.api.EventSubscriber;
import sx.blah.discord.handle.impl.events.*;

/**
 * Very core events handler, should be running independently from the whole events manager thingy.
 * It handles things like auto reconnect after gateway disconnection, etc.
 */
public class CoreEventsHandler
{
	/**
	 * Logger
	 */
	private static Logger LOGGER = LogManager.getLogger(CoreEventsHandler.class);

	/**
	 * Singleton instance
	 */
	private static CoreEventsHandler INSTANCE = new CoreEventsHandler();

	/**
	 * Get current instance
	 */
	public static CoreEventsHandler getInstance()
	{
		return INSTANCE;
	}

	/**
	 * Basic constructor, enforcing singleton
	 */
	private CoreEventsHandler()
	{}

	@EventSubscriber
	public void onReady(ReadyEvent event)
	{
		LOGGER.info("Connection with user #" + event.getClient().getOurUser().getID() + " ready.");
	}

	@EventSubscriber
	public void onDiscordDisconnected(DiscordDisconnectedEvent event)
	{
		LOGGER.warn("Discord connection with user #" + event.getClient().getOurUser().getID() + "lost (" + event.getReason().toString() + "). Reconnecting");

	}

	@EventSubscriber
	public void onMessageSend(MessageSendEvent event)
	{
		LOGGER.trace("Sent message to channel #" + event.getMessage().getChannel().getID() + ".");
	}

	@EventSubscriber
	public void onMention(MentionEvent event)
	{
		LOGGER.trace("Received mention from channel #" + event.getMessage().getChannel().getID() + ".");
	}

	@EventSubscriber
	public void onMessageReceived(MessageReceivedEvent event)
	{
		LOGGER.trace("Received message from channel #" + event.getMessage().getChannel().getID() + ".");
	}

	@EventSubscriber
	public void onGuildUnavailable(GuildUnavailableEvent event)
	{
		LOGGER.warn("Guild #" + event.getGuild().getID() + " is unavailable.");
	}

	@EventSubscriber
	public void onGuildCreate(GuildCreateEvent event)
	{
		LOGGER.info("Joined guild #" + event.getGuild().getID() + ".");
	}
}
